@@ -73,12 +73,12 @@ class AbbRcfClient(compas_rrc.AbbClient):
 
         Parameters
         ----------
-        timeout : :obj:`float`, optional
+        timeout
             Timeout for reply. Defaults to ``10``.
 
         Raises
         ------
-        :exc:`TimeoutError`
+        :exc:`compas_rrc.TimeoutError`
             If no reply is returned before timeout.
         """
         self.send_and_wait(
@@ -86,39 +86,46 @@ class AbbRcfClient(compas_rrc.AbbClient):
             timeout=timeout,
         )
 
-    def check_reconnect(
+    def ensure_connection(
         self,
         timeout_ping: float = 5,
         wait_after_up: float = 2,
-        tries: int = 3,
+        tries: int = 10,
     ):
         """Check connection to ABB controller and restart abb-driver if necessary.
 
         Parameters
         ----------
-        timeout_ping : :obj:`float`, optional
+        timeout_ping
             Timeout for ping response.
-        wait_after_up : :obj:`float`, optional
+        wait_after_up
             Time to wait to ping after `abb-driver` container started.
+        tries
+            How many times to ping before raising error.
 
         Raises
         ------
-        :exc:`TimeoutError`
-            If no reply is returned before timeout.
+        :exc:`compas_rrc.TimeoutException`
+            If no reply is returned to second ping before timeout.
         """
-        for _ in range(tries):
-            try:
-                log.debug("Pinging robot")
-                self.ping(timeout_ping)
-                log.debug("Breaking loop after successful ping.")
-                break
-            except compas_rrc.TimeoutException:
-                log.info("No response from controller, restarting abb-driver service.")
-                restart_container(DRIVER_CONTAINER_NAME)
+        try:
+            log.debug("Pinging robot")
+            self.ping(timeout=timeout_ping)
+        except compas_rrc.TimeoutException:
+            log.info("No response from controller, restarting abb-driver service.")
+            restart_container(DRIVER_CONTAINER_NAME)
 
-                time.sleep(wait_after_up)
-        else:
-            raise compas_rrc.TimeoutException("Failed to connect to robot.")
+            time.sleep(wait_after_up)
+
+            for _ in range(tries - 1):
+                try:
+                    self.ping(timeout_ping)
+                except compas_rrc.TimeoutException:
+                    pass
+                else:
+                    return
+
+            raise  # If there's still no response after n tries, raise exception
 
 
 class AbbRcfFabricationClient(AbbRcfClient):
@@ -179,8 +186,11 @@ class AbbRcfFabricationClient(AbbRcfClient):
                 f"default_travel_trajectories: {self.default_travel_trajectories}"
             )
 
-    def check_reconnect(
-        self, timeout_ping: float = None, wait_after_up: float = None, tries: int = 3
+    def ensure_connection(
+        self,
+        timeout_ping: typing.Optional[float] = None,
+        wait_after_up: typing.Optional[float] = None,
+        tries: int = 10,
     ) -> None:
         """Check connection to ABB controller and restart abb-driver if necessary.
 
@@ -194,16 +204,12 @@ class AbbRcfFabricationClient(AbbRcfClient):
         :exc:`TimeoutError`
             If no reply is returned before timeout.
         """
-        if not timeout_ping:
+        if timeout_ping is None:
             timeout_ping = self.docker_cfg.timeout_ping
-        if not wait_after_up:
+        if wait_after_up is None:
             wait_after_up = self.docker_cfg.sleep_after_up
 
-        # Fixing mypy warning about incompatible types in super meth call
-        assert timeout_ping is not None
-        assert wait_after_up is not None
-
-        super().check_reconnect(
+        super().ensure_connection(
             timeout_ping=timeout_ping,
             wait_after_up=wait_after_up,
             tries=tries,
@@ -239,7 +245,8 @@ class AbbRcfFabricationClient(AbbRcfClient):
                 self.EXTERNAL_AXES_DUMMY,
                 self.speed.travel,
                 self.zone.travel,
-            )
+            ),
+            timeout=60,
         )
 
     def post_procedure(self) -> None:
@@ -261,7 +268,7 @@ class AbbRcfFabricationClient(AbbRcfClient):
     def pick_element(self) -> None:
         """Send movement and IO instructions to pick up fabrication element."""
         self.send(compas_rrc.SetTool(self.pick_place_tool.name))
-        log.debug("Tool {self.pick_place_tool.name} set.")
+        log.debug(f"Tool {self.pick_place_tool.name} set.")
         self.send(compas_rrc.SetWorkObject(self.wobjs.pick))
         log.debug(f"Work object {self.wobjs.pick} set.")
 
@@ -271,7 +278,7 @@ class AbbRcfFabricationClient(AbbRcfClient):
             MoveToRobtarget(
                 element.get_egress_frame(),
                 self.EXTERNAL_AXES_DUMMY,
-                self.speed.travel,
+                self.speed.pick,
                 self.zone.pick,
             )
         )
@@ -280,7 +287,8 @@ class AbbRcfFabricationClient(AbbRcfClient):
             MoveToRobtarget(
                 element.get_top_frame(),
                 self.EXTERNAL_AXES_DUMMY,
-                self.speed.pick_place,
+                # TODO: Set up conf for speed pick specificly
+                self.speed.pick,
                 compas_rrc.Zone.FINE,
             )
         )
@@ -292,7 +300,7 @@ class AbbRcfFabricationClient(AbbRcfClient):
             MoveToRobtarget(
                 element.get_egress_frame(),
                 self.EXTERNAL_AXES_DUMMY,
-                self.speed.pick_place,
+                self.speed.pick,
                 self.zone.pick,
                 motion_type=Motion.LINEAR,
             )
@@ -344,7 +352,7 @@ class AbbRcfFabricationClient(AbbRcfClient):
         # Last place motion
         self.execute_trajectory(
             place_trajectories[-1],
-            self.speed.pick_place,
+            self.speed.place,
             self.zone.place,
             motion_type=Motion.LINEAR,
         )
@@ -352,7 +360,7 @@ class AbbRcfFabricationClient(AbbRcfClient):
         return_place_trajectories = self._get_return_place_trajectories(element)
         self.execute_trajectory(
             return_place_trajectories[0],
-            self.speed.pick_place,
+            self.speed.place,
             self.zone.place,
         )
 
@@ -410,7 +418,7 @@ class AbbRcfFabricationClient(AbbRcfClient):
         blocking: bool = False,
         stop_at_last: bool = False,
         motion_type: int = Motion.JOINT,
-    ) -> None:
+    ) -> compas_rrc.FutureResult:
         """Execute a :class:`~compas_fab.JointTrajectory`.
 
         Parameters
@@ -430,35 +438,36 @@ class AbbRcfFabricationClient(AbbRcfClient):
             should the last trajectory points zone be set to `compas_rrc.Zone.FINE`.
         """
         log.debug(f"Trajectory: {trajectory}.")
-        kwargs = {}
 
-        if trajectory.trajectory_type == MinimalTrajectory.JOINT_TRAJECTORY:
-            trajectory_pts = trajectory.as_robot_joints_points()
-            instruction = MoveToJoints
+        motion_class, trajectory_pts = trajectory.to_compas_rrc()
 
-        elif trajectory.trajectory_type == MinimalTrajectory.FRAME_TRAJECTORY:
-            trajectory_pts = trajectory.points
-            instruction = MoveToRobtarget
-            kwargs["motion_type"] = motion_type
-        else:
-            raise RuntimeError(f"Trajectory not recognized: {trajectory}.")
+        motion_args = [
+            self.EXTERNAL_AXES_DUMMY,
+            speed,
+            zone,
+        ]
+
+        motion_kwargs = {}
+
+        if trajectory.trajectory_type == MinimalTrajectory.FRAME_TRAJECTORY:
+            # ignore motion_type if trajectory is joint trajectory
+            motion_kwargs["motion_type"] = motion_type
 
         for pt in trajectory_pts[:-1]:  # skip last
-            self.send(instruction(pt, self.EXTERNAL_AXES_DUMMY, speed, zone, **kwargs))
+            self.send(motion_class(pt, *motion_args, **motion_kwargs))
 
+        # modify last (zone) arg for last trajectory pt
+        motion_args[-1] = compas_rrc.Zone.FINE if stop_at_last else zone
+
+        # send and wait on last if blocking
         if blocking:
-            send_method_last_pt = self.send_and_wait
-        else:
-            send_method_last_pt = self.send
-
-        if stop_at_last:
-            zone = compas_rrc.Zone.FINE
-
-        # send last
-        send_method_last_pt(
-            instruction(
-                trajectory_pts[-1], self.EXTERNAL_AXES_DUMMY, speed, zone, **kwargs
+            return self.send_and_wait(
+                motion_class(trajectory_pts[-1], *motion_args, **motion_kwargs),
+                timeout=60,
             )
+
+        return self.send(
+            motion_class(trajectory_pts[-1], *motion_args, **motion_kwargs)
         )
 
     def retract_needles(self) -> None:
